Driver for Text OLED display - 20x4 Winstar or Newhaven, with Winstar WS0010 driver IC

Revision:
2:c7834290ea1c
Parent:
1:863e06094dfd
--- a/TextOLED20x4.h	Wed Dec 19 13:03:42 2012 +0000
+++ b/TextOLED20x4.h	Wed Dec 19 14:25:18 2012 +0000
@@ -1,4 +1,5 @@
 /* mbed TextLCD Library, for a 4-bit LCD based on HD44780
  * Copyright (c) 2007-2010, sford, http://mbed.org
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -20,27 +21,29 @@
  * THE SOFTWARE.
  */
 
-#ifndef MBED_TEXTLCD_H
-#define MBED_TEXTLCD_H
+#ifndef MBED_TextOLED20x4_H
+#define MBED_TextOLED20x4_H
+
+
 
 #include "mbed.h"
 
 /** A TextLCD interface for driving 4-bit HD44780-based LCDs
  *
  * Currently supports 16x2, 20x2 and 20x4 panels
  *
  * @code
  * #include "mbed.h"
- * #include "TextLCD.h"
+ * #include "TextOLED20x4.h"
  * 
- * TextLCD lcd(p10, p12, p15, p16, p29, p30); // rs, e, d4-d7
+ * TextOLED20x4 lcd(p10, p12, p15, p16, p29, p30); // rs, e, d4-d7
  * 
  * int main() {
  *     lcd.printf("Hello World!\n");
  * }
  * @endcode
  */
-class TextLCD : public Stream {
+class TextOLED20x4 : public Stream {
 public:
 
     /** LCD panel format */
@@ -51,14 +54,14 @@
         , LCD20x4   /**< 20x4 LCD panel */
     };
 
-    /** Create a TextLCD interface
+    /** Create a TextOLED20x4 interface
      *
      * @param rs    Instruction/data control line
      * @param e     Enable line (clock)
      * @param d4-d7 Data lines for using as a 4-bit interface
      * @param type  Sets the panel size/addressing mode (default = LCD16x2)
      */
-    TextLCD(PinName rs, PinName e, PinName d4, PinName d5, PinName d6, PinName d7, LCDType type = LCD16x2);
+    TextOLED20x4(PinName rs, PinName e, PinName d4, PinName d5, PinName d6, PinName d7, LCDType type = LCD16x2);
 
 #if DOXYGEN_ONLY
     /** Write a character to the LCD
@@ -1,4 +1,5 @@
-/* mbed TextLCD Library, for a 4-bit LCD based on HD44780
+/* mbed TextOLED20x4 Library, for a 4-bit LCD based on HD44780
+ * copyleft Rod Coleman 2012
  * Copyright (c) 2007-2010, sford, http://mbed.org
  *
@@ -20,27 +21,29 @@
 #include "mbed.h"
 
-/** A TextLCD interface for driving 4-bit HD44780-based LCDs
+/** A TextOLED20x4 interface for driving 4-bit HD44780-based LCDs
  *
  * Currently supports 16x2, 20x2 and 20x4 panels